@@ -1,5 +1,5 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.01';
+$Net::Kubernetes::VERSION = '0.02';
 use Moose;
 use Data::Dumper;
 require Net::Kubernetes::Namespace;
@@ -19,7 +19,7 @@ Net::Kubernetes
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -132,7 +132,12 @@ These methods can be called directly on a resource object.
 
 =over 1
 
-=item $resource->deltete
+=item $resource->delete
+
+=item $resource->refresh
+
+This method is only available for resources which have a status (currently everything
+other than secretes).
 
 =cut
 
