@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource;
-$Net::Kubernetes::Resource::VERSION = '0.01';
+$Net::Kubernetes::Resource::VERSION = '0.02';
 use Moose;
 
 =head1 NAME
@@ -8,7 +8,7 @@ Net::Kubernetes::Resource
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =cut
 
@@ -36,8 +36,11 @@ has metadata => (
 sub delete {
 	my($self) = @_;
 	my($res) = $self->ua->request($self->create_request(DELETE => $self->url.'/'.$self->base_path));
-	use Data::Dumper;
-	print Dumper($res)."\n";
+	if ($res->is_success) {
+		return 1;
+	}
+	return 0;
 }
 
+
 return 42;
